aboutsummaryrefslogtreecommitdiff
path: root/sql
diff options
context:
space:
mode:
authorAndrew Or <andrew@databricks.com>2015-06-19 17:39:26 -0700
committerAndrew Or <andrew@databricks.com>2015-06-19 17:39:26 -0700
commitbec40e52be1bbe8fd6f3a1daa6284429d6b5d841 (patch)
treed046451806f64ec035b5a77b28fb3e57a2379350 /sql
parent093c34838d1db7a9375f36a9a2ab5d96a23ae683 (diff)
downloadspark-bec40e52be1bbe8fd6f3a1daa6284429d6b5d841.tar.gz
spark-bec40e52be1bbe8fd6f3a1daa6284429d6b5d841.tar.bz2
spark-bec40e52be1bbe8fd6f3a1daa6284429d6b5d841.zip
[HOTFIX] [SPARK-8489] Correct JIRA number in previous commit
It should be SPARK-8489, not SPARK-8498.
Diffstat (limited to 'sql')
-rw-r--r--sql/hive/src/test/resources/regression-test-SPARK-8489/Main.scala (renamed from sql/hive/src/test/resources/regression-test-SPARK-8498/Main.scala)6
-rw-r--r--sql/hive/src/test/resources/regression-test-SPARK-8489/MyCoolClass.scala (renamed from sql/hive/src/test/resources/regression-test-SPARK-8498/MyCoolClass.scala)2
-rw-r--r--sql/hive/src/test/resources/regression-test-SPARK-8489/test.jar (renamed from sql/hive/src/test/resources/regression-test-SPARK-8498/test.jar)bin6811 -> 6811 bytes
-rw-r--r--sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala8
4 files changed, 8 insertions, 8 deletions
diff --git a/sql/hive/src/test/resources/regression-test-SPARK-8498/MyCoolClass.scala b/sql/hive/src/test/resources/regression-test-SPARK-8489/MyCoolClass.scala
index a72c063a38..b1681745c2 100644
--- a/sql/hive/src/test/resources/regression-test-SPARK-8498/MyCoolClass.scala
+++ b/sql/hive/src/test/resources/regression-test-SPARK-8489/MyCoolClass.scala
@@ -15,6 +15,6 @@
* limitations under the License.
*/
-/** Dummy class used in regression test SPARK-8498. */
+/** Dummy class used in regression test SPARK-8489. */
case class MyCoolClass(past: String, present: String, future: String)
diff --git a/sql/hive/src/test/resources/regression-test-SPARK-8498/test.jar b/sql/hive/src/test/resources/regression-test-SPARK-8489/test.jar
index 4f59fba9ea..4f59fba9ea 100644
--- a/sql/hive/src/test/resources/regression-test-SPARK-8498/test.jar
+++ b/sql/hive/src/test/resources/regression-test-SPARK-8489/test.jar
Binary files differ
diff --git a/sql/hive/src/test/resources/regression-test-SPARK-8498/Main.scala b/sql/hive/src/test/resources/regression-test-SPARK-8489/Main.scala
index 858dd6b5dd..e1715177e3 100644
--- a/sql/hive/src/test/resources/regression-test-SPARK-8498/Main.scala
+++ b/sql/hive/src/test/resources/regression-test-SPARK-8489/Main.scala
@@ -19,7 +19,7 @@ import org.apache.spark.{SparkConf, SparkContext}
import org.apache.spark.sql.hive.HiveContext
/**
* Entry point in test application for SPARK-8498.
*
* This file is not meant to be compiled during tests. It is already included
* in a pre-built "test.jar" located in the same directory as this file.
@@ -30,14 +30,14 @@ import org.apache.spark.sql.hive.HiveContext
*/
object Main {
def main(args: Array[String]) {
- println("Running regression test for SPARK-8498.")
+ println("Running regression test for SPARK-8489.")
val sc = new SparkContext("local", "testing")
val hc = new HiveContext(sc)
// This line should not throw scala.reflect.internal.MissingRequirementError.
// See SPARK-8470 for more detail.
val df = hc.createDataFrame(Seq(MyCoolClass("1", "2", "3")))
df.collect()
- println("Regression test for SPARK-8498 success!")
+ println("Regression test for SPARK-8489 success!")
}
}
@@ -19,7 +19,7 @@ import org.apache.spark.{SparkConf, SparkContext}
import org.apache.spark.sql.hive.HiveContext
/**
- * Entry point in test application for SPARK-8498.
+ * Entry point in test application for SPARK-8489.
*
* This file is not meant to be compiled during tests. It is already included
diff --git a/sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala b/sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala
index 820af801a7..ab443032be 100644
--- a/sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala
+++ b/sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala
@@ -67,13 +67,13 @@ class HiveSparkSubmitSuite
runSparkSubmit(args)
}
- test("SPARK-8498: MissingRequirementError during reflection") {
- // This test uses a pre-built jar to test SPARK-8498. In a nutshell, this test creates
+ test("SPARK-8489: MissingRequirementError during reflection") {
+ // This test uses a pre-built jar to test SPARK-8489. In a nutshell, this test creates
// a HiveContext and uses it to create a data frame from an RDD using reflection.
// Before the fix in SPARK-8470, this results in a MissingRequirementError because
// the HiveContext code mistakenly overrides the class loader that contains user classes.
- // For more detail, see sql/hive/src/test/resources/regression-test-SPARK-8498/*scala.
- val testJar = "sql/hive/src/test/resources/regression-test-SPARK-8498/test.jar"
+ // For more detail, see sql/hive/src/test/resources/regression-test-SPARK-8489/*scala.
+ val testJar = "sql/hive/src/test/resources/regression-test-SPARK-8489/test.jar"
val args = Seq("--class", "Main", testJar)
runSparkSubmit(args)
}